Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6054)

Unified Diff: chrome/renderer/render_thread.h

Issue 17281: This is a rename of the term 'Greasemonkey' to 'user script' in Chromium. (Closed)
Patch Set: Fix indent Created 11 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/renderer/greasemonkey_slave_unittest.cc ('k') | chrome/renderer/render_thread.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/renderer/render_thread.h
diff --git a/chrome/renderer/render_thread.h b/chrome/renderer/render_thread.h
index c9dbea42ca59aec7a033955b31fdc7c5b82febdc..7884e9f388ccc90602c8dbb86c9a8bc869123f4d 100644
--- a/chrome/renderer/render_thread.h
+++ b/chrome/renderer/render_thread.h
@@ -19,7 +19,7 @@ class VisitedLinkSlave;
struct WebPreferences;
class RenderDnsMaster;
class NotificationService;
-class GreasemonkeySlave;
+class UserScriptSlave;
// The RenderThreadBase is the minimal interface that a RenderView/Widget
// expects from a render thread. The interface basically abstracts a way to send
@@ -70,8 +70,8 @@ class RenderThread : public IPC::Channel::Listener,
// Gets the VisitedLinkSlave instance for this thread
VisitedLinkSlave* visited_link_slave() const { return visited_link_slave_; }
- // Gets the GreasemonkeySlave instance for this thread
- GreasemonkeySlave* greasemonkey_slave() const { return greasemonkey_slave_; }
+ // Gets the UserScriptSlave instance for this thread
+ UserScriptSlave* user_script_slave() const { return user_script_slave_; }
// Do DNS prefetch resolution of a hostname.
void Resolve(const char* name, size_t length);
@@ -96,7 +96,7 @@ class RenderThread : public IPC::Channel::Listener,
private:
void OnUpdateVisitedLinks(base::SharedMemoryHandle table);
- void OnUpdateGreasemonkeyScripts(base::SharedMemoryHandle table);
+ void OnUpdateUserScripts(base::SharedMemoryHandle table);
void OnPluginMessage(const FilePath& plugin_path,
const std::vector<uint8>& data);
@@ -128,7 +128,7 @@ class RenderThread : public IPC::Channel::Listener,
// These objects live solely on the render thread.
VisitedLinkSlave* visited_link_slave_;
- GreasemonkeySlave* greasemonkey_slave_;
+ UserScriptSlave* user_script_slave_;
scoped_ptr<RenderDnsMaster> render_dns_master_;
« no previous file with comments | « chrome/renderer/greasemonkey_slave_unittest.cc ('k') | chrome/renderer/render_thread.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698